Class: Google::Apis::ArtifactregistryV1beta2::ArtifactRegistryService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ArtifactregistryV1beta2::ArtifactRegistryService
- Defined in:
- lib/google/apis/artifactregistry_v1beta2/service.rb
Overview
Artifact Registry API
Store and manage build artifacts in a scalable and integrated service built on Google infrastructure.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://artifactregistry.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Creates a repository.
-
#create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Creates a tag.
-
#delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a repository and all of its contents.
-
#delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a package and all of its versions and tags.
-
#delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Empty
Deletes a tag.
-
#delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a version and all of its content.
-
#download_project_location_repository_file(name, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse
Download a file.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Location
Gets information about a location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Gets a repository.
-
#get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File
Gets a file.
-
#get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Gets the IAM policy for a given resource.
-
#get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Gets a package.
-
#get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Gets a tag.
-
#get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Version
Gets a version.
-
#get_project_project_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Retrieves the Settings for the Project.
-
#import_apt_artifacts(parent, import_apt_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Apt artifacts.
-
#import_yum_artifacts(parent, import_yum_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Yum (RPM) artifacts.
-
#initialize ⇒ ArtifactRegistryService
constructor
A new instance of ArtifactRegistryService.
-
#list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse
Lists repositories.
-
#list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListFilesResponse
Lists files.
-
#list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListTagsResponse
Lists tags.
-
#list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse
Lists versions.
-
#list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse
Lists packages.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Updates a repository.
-
#patch_project_location_repository_package(name, package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Updates a package.
-
#patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Updates a tag.
-
#set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Updates the IAM policy for a given resource.
-
#test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse
Tests if the caller has a list of permissions on a resource.
-
#update_project_project_settings(name, project_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Updates the Settings for the Project.
-
#upload_apt_artifact(parent, upload_apt_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse
Directly uploads an Apt artifact.
-
#upload_yum_artifact(parent, upload_yum_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse
Directly uploads a Yum artifact.
Constructor Details
#initialize ⇒ ArtifactRegistryService
Returns a new instance of ArtifactRegistryService.
48 49 50 51 52 53 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-artifactregistry_v1beta2', client_version: Google::Apis::ArtifactregistryV1beta2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Creates a repository. The returned Operation will finish once the repository has been created. Its response will be the created Repository.
263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 263 def create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/repositories', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.request_object = repository_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['parent'] = parent unless parent.nil? command.query['repositoryId'] = repository_id unless repository_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Creates a tag.
909 910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 909 def create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/tags', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.request_object = tag_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Tag command.params['parent'] = parent unless parent.nil? command.query['tagId'] = tag_id unless tag_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a repository and all of its contents. The returned Operation will finish once the repository has been deleted. It will not have any Operation metadata and will return a google.protobuf.Empty response.
298 299 300 301 302 303 304 305 306 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 298 def delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a package and all of its versions and tags. The returned operation will complete once the package has been deleted.
767 768 769 770 771 772 773 774 775 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 767 def delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Empty
Deletes a tag.
942 943 944 945 946 947 948 949 950 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 942 def delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Empty::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a version and all of its content. The returned operation will complete once the version has been deleted.
1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1102 def delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#download_project_location_repository_file(name, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse
Download a file.
635 636 637 638 639 640 641 642 643 644 645 646 647 648 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 635 def download_project_location_repository_file(name, fields: nil, quota_user: nil, download_dest: nil, options: nil, &block) if download_dest.nil? command = make_simple_command(:get, 'v1beta2/{+name}:download', ) else command = make_download_command(:get, 'v1beta2/{+name}:download', ) command.download_dest = download_dest end command.response_representation = Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Location
Gets information about a location.
142 143 144 145 146 147 148 149 150 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 142 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Location::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
229 230 231 232 233 234 235 236 237 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 229 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Gets a repository.
328 329 330 331 332 333 334 335 336 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 328 def get_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Repository command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File
Gets a file.
670 671 672 673 674 675 676 677 678 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 670 def get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Gets the IAM policy for a given resource.
371 372 373 374 375 376 377 378 379 380 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 371 def get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Policy::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Gets a package.
797 798 799 800 801 802 803 804 805 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 797 def get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Package::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Package command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Gets a tag.
972 973 974 975 976 977 978 979 980 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 972 def get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Tag command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Version
Gets a version
1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1135 def get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Version::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Version command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_project_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Retrieves the Settings for the Project.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 75 def get_project_project_settings(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ProjectSettings::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ProjectSettings command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_apt_artifacts(parent, import_apt_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Apt artifacts. The returned Operation will complete once the resources are imported. Package, Version, and File resources are created based on the imported artifacts. Imported artifacts that conflict with existing resources are ignored.
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 555 def import_apt_artifacts(parent, import_apt_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/aptArtifacts:import', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::ImportAptArtifactsRequest::Representation command.request_object = import_apt_artifacts_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_yum_artifacts(parent, import_yum_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Yum (RPM) artifacts. The returned Operation will complete once the resources are imported. Package, Version, and File resources are created based on the imported artifacts. Imported artifacts that conflict with existing resources are ignored.
1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1212 def import_yum_artifacts(parent, import_yum_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/yumArtifacts:import', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::ImportYumArtifactsRequest::Representation command.request_object = import_yum_artifacts_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse
Lists repositories.
408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 408 def list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/repositories', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListFilesResponse
Lists files.
733 734 735 736 737 738 739 740 741 742 743 744 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 733 def list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/files', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListFilesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListFilesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListTagsResponse
Lists tags.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1024 def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/tags', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListTagsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListTagsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse
Lists versions.
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1174 def list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/versions', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse
Lists packages.
833 834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 833 def list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/packages', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 194 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}/locations', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Updates a repository.
448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 448 def patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.request_object = repository_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Repository command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository_package(name, package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Updates a package.
873 874 875 876 877 878 879 880 881 882 883 884 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 873 def patch_project_location_repository_package(name, package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Package::Representation command.request_object = package_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Package::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Package command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Updates a tag.
1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1065 def patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.request_object = tag_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Tag command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Updates the IAM policy for a given resource.
484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 484 def set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Policy::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse
Tests if the caller has a list of permissions on a resource.
519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 519 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_project_settings(name, project_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Updates the Settings for the Project.
109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 109 def update_project_project_settings(name, project_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::ProjectSettings::Representation command.request_object = project_settings_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::ProjectSettings::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ProjectSettings command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upload_apt_artifact(parent, upload_apt_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse
Directly uploads an Apt artifact. The returned Operation will complete once the resources are uploaded. Package, Version, and File resources are created based on the imported artifact. Imported artifacts that conflict with existing resources are ignored.
595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 595 def upload_apt_artifact(parent, upload_apt_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil, &block) if upload_source.nil? command = make_simple_command(:post, 'v1beta2/{+parent}/aptArtifacts:create', ) else command = make_upload_command(:post, 'v1beta2/{+parent}/aptArtifacts:create', ) command.upload_source = upload_source command.upload_content_type = content_type end command.request_representation = Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactRequest::Representation command.request_object = upload_apt_artifact_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upload_yum_artifact(parent, upload_yum_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse
Directly uploads a Yum artifact. The returned Operation will complete once the resources are uploaded. Package, Version, and File resources are created based on the imported artifact. Imported artifacts that conflict with existing resources are ignored.
1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1252 def upload_yum_artifact(parent, upload_yum_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil, &block) if upload_source.nil? command = make_simple_command(:post, 'v1beta2/{+parent}/yumArtifacts:create', ) else command = make_upload_command(:post, 'v1beta2/{+parent}/yumArtifacts:create', ) command.upload_source = upload_source command.upload_content_type = content_type end command.request_representation = Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactRequest::Representation command.request_object = upload_yum_artifact_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |