Class: Google::Apis::ArtifactregistryV1beta2::ArtifactRegistryService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ArtifactregistryV1beta2::ArtifactRegistryService
- Defined in:
- lib/google/apis/artifactregistry_v1beta2/service.rb
Overview
Artifact Registry API
Store and manage build artifacts in a scalable and integrated service built on Google infrastructure.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://artifactregistry.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Creates a repository.
-
#create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Creates a tag.
-
#delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a repository and all of its contents.
-
#delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a package and all of its versions and tags.
-
#delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Empty
Deletes a tag.
-
#delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a version and all of its content.
-
#download_project_location_repository_file(name, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse
Download a file.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Location
Gets information about a location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Gets a repository.
-
#get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File
Gets a file.
-
#get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Gets the IAM policy for a given resource.
-
#get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Gets a package.
-
#get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Gets a tag.
-
#get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Version
Gets a version.
-
#get_project_project_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Retrieves the Settings for the Project.
-
#import_apt_artifacts(parent, import_apt_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Apt artifacts.
-
#import_yum_artifacts(parent, import_yum_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Yum (RPM) artifacts.
-
#initialize ⇒ ArtifactRegistryService
constructor
A new instance of ArtifactRegistryService.
-
#list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse
Lists repositories.
-
#list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListFilesResponse
Lists files.
-
#list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListTagsResponse
Lists tags.
-
#list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse
Lists versions.
-
#list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse
Lists packages.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Updates a repository.
-
#patch_project_location_repository_package(name, package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Updates a package.
-
#patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Updates a tag.
-
#set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Updates the IAM policy for a given resource.
-
#test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse
Tests if the caller has a list of permissions on a resource.
-
#update_project_project_settings(name, project_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Updates the Settings for the Project.
-
#upload_apt_artifact(parent, upload_apt_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse
Directly uploads an Apt artifact.
-
#upload_yum_artifact(parent, upload_yum_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse
Directly uploads a Yum artifact.
Constructor Details
#initialize ⇒ ArtifactRegistryService
Returns a new instance of ArtifactRegistryService.
48 49 50 51 52 53 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-artifactregistry_v1beta2', client_version: Google::Apis::ArtifactregistryV1beta2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Creates a repository. The returned Operation will finish once the repository has been created. Its response will be the created Repository.
258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 258 def create_project_location_repository(parent, repository_object = nil, repository_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/repositories', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.request_object = repository_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['parent'] = parent unless parent.nil? command.query['repositoryId'] = repository_id unless repository_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Creates a tag.
904 905 906 907 908 909 910 911 912 913 914 915 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 904 def create_project_location_repository_package_tag(parent, tag_object = nil, tag_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/tags', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.request_object = tag_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Tag command.params['parent'] = parent unless parent.nil? command.query['tagId'] = tag_id unless tag_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a repository and all of its contents. The returned Operation will finish once the repository has been deleted. It will not have any Operation metadata and will return a google.protobuf.Empty response.
293 294 295 296 297 298 299 300 301 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 293 def delete_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a package and all of its versions and tags. The returned operation will complete once the package has been deleted.
762 763 764 765 766 767 768 769 770 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 762 def delete_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Empty
Deletes a tag.
937 938 939 940 941 942 943 944 945 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 937 def delete_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Empty::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Deletes a version and all of its content. The returned operation will complete once the version has been deleted.
1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1097 def delete_project_location_repository_package_version(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#download_project_location_repository_file(name, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse
Download a file.
630 631 632 633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 630 def download_project_location_repository_file(name, fields: nil, quota_user: nil, download_dest: nil, options: nil, &block) if download_dest.nil? command = make_simple_command(:get, 'v1beta2/{+name}:download', ) else command = make_download_command(:get, 'v1beta2/{+name}:download', ) command.download_dest = download_dest end command.response_representation = Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::DownloadFileResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Location
Gets information about a location.
142 143 144 145 146 147 148 149 150 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 142 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Location::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
224 225 226 227 228 229 230 231 232 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 224 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Gets a repository.
323 324 325 326 327 328 329 330 331 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 323 def get_project_location_repository(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Repository command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File
Gets a file.
665 666 667 668 669 670 671 672 673 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 665 def get_project_location_repository_file(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::GoogleDevtoolsArtifactregistryV1beta2File command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Gets the IAM policy for a given resource.
366 367 368 369 370 371 372 373 374 375 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 366 def get_project_location_repository_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Policy::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Gets a package.
792 793 794 795 796 797 798 799 800 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 792 def get_project_location_repository_package(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Package::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Package command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Gets a tag.
967 968 969 970 971 972 973 974 975 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 967 def get_project_location_repository_package_tag(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Tag command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Version
Gets a version
1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1130 def get_project_location_repository_package_version(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::Version::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Version command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_project_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Retrieves the Settings for the Project.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 75 def get_project_project_settings(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ProjectSettings::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ProjectSettings command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_apt_artifacts(parent, import_apt_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Apt artifacts. The returned Operation will complete once the resources are imported. Package, Version, and File resources are created based on the imported artifacts. Imported artifacts that conflict with existing resources are ignored.
550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 550 def import_apt_artifacts(parent, import_apt_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/aptArtifacts:import', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::ImportAptArtifactsRequest::Representation command.request_object = import_apt_artifacts_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_yum_artifacts(parent, import_yum_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Operation
Imports Yum (RPM) artifacts. The returned Operation will complete once the resources are imported. Package, Version, and File resources are created based on the imported artifacts. Imported artifacts that conflict with existing resources are ignored.
1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1207 def import_yum_artifacts(parent, import_yum_artifacts_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+parent}/yumArtifacts:import', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::ImportYumArtifactsRequest::Representation command.request_object = import_yum_artifacts_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Operation::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse
Lists repositories.
403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 403 def list_project_location_repositories(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/repositories', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListRepositoriesResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListFilesResponse
Lists files.
728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 728 def list_project_location_repository_files(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/files', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListFilesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListFilesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_package_tags(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListTagsResponse
Lists tags.
1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1019 def (parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/tags', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListTagsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListTagsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse
Lists versions.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1169 def list_project_location_repository_package_versions(parent, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/versions', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse
Lists packages.
828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 828 def list_project_location_repository_packages(parent, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+parent}/packages', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListPackagesResponse command.params['parent'] = parent unless parent.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 189 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta2/{+name}/locations', ) command.response_representation = Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Repository
Updates a repository.
443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 443 def patch_project_location_repository(name, repository_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.request_object = repository_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Repository::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Repository command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository_package(name, package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Package
Updates a package.
868 869 870 871 872 873 874 875 876 877 878 879 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 868 def patch_project_location_repository_package(name, package_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Package::Representation command.request_object = package_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Package::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Package command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Tag
Updates a tag.
1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1060 def patch_project_location_repository_package_tag(name, tag_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.request_object = tag_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Tag::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Tag command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::Policy
Updates the IAM policy for a given resource.
479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 479 def set_repository_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::Policy::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_repository_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse
Tests if the caller has a list of permissions on a resource.
514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 514 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta2/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_project_settings(name, project_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::ProjectSettings
Updates the Settings for the Project.
109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 109 def update_project_project_settings(name, project_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta2/{+name}', ) command.request_representation = Google::Apis::ArtifactregistryV1beta2::ProjectSettings::Representation command.request_object = project_settings_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::ProjectSettings::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::ProjectSettings command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upload_apt_artifact(parent, upload_apt_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse
Directly uploads an Apt artifact. The returned Operation will complete once the resources are uploaded. Package, Version, and File resources are created based on the imported artifact. Imported artifacts that conflict with existing resources are ignored.
590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 590 def upload_apt_artifact(parent, upload_apt_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil, &block) if upload_source.nil? command = make_simple_command(:post, 'v1beta2/{+parent}/aptArtifacts:create', ) else command = make_upload_command(:post, 'v1beta2/{+parent}/aptArtifacts:create', ) command.upload_source = upload_source command.upload_content_type = content_type end command.request_representation = Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactRequest::Representation command.request_object = upload_apt_artifact_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::UploadAptArtifactMediaResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upload_yum_artifact(parent, upload_yum_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse
Directly uploads a Yum artifact. The returned Operation will complete once the resources are uploaded. Package, Version, and File resources are created based on the imported artifact. Imported artifacts that conflict with existing resources are ignored.
1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 |
# File 'lib/google/apis/artifactregistry_v1beta2/service.rb', line 1247 def upload_yum_artifact(parent, upload_yum_artifact_request_object = nil, fields: nil, quota_user: nil, upload_source: nil, content_type: nil, options: nil, &block) if upload_source.nil? command = make_simple_command(:post, 'v1beta2/{+parent}/yumArtifacts:create', ) else command = make_upload_command(:post, 'v1beta2/{+parent}/yumArtifacts:create', ) command.upload_source = upload_source command.upload_content_type = content_type end command.request_representation = Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactRequest::Representation command.request_object = upload_yum_artifact_request_object command.response_representation = Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse::Representation command.response_class = Google::Apis::ArtifactregistryV1beta2::UploadYumArtifactMediaResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |